@@ -5,11 +5,11 @@ from collections import Counter
 
 import nltk
 from nltk.tokenize import sent_tokenize, word_tokenize
-from text.np_extractor import NPExtractor
-from text.decorators import cached_property
-from text.utils import lowerstrip, strip_punc
-from text.inflect import singularize, pluralize
-from text.sentiments import sentiment as _sentiment
+from .np_extractor import NPExtractor
+from .decorators import cached_property
+from .utils import lowerstrip, strip_punc
+from .inflect import singularize, pluralize
+from .sentiment import sentiment as _sentiment
 
 
 class WordList(list):
